================
Widget Reference
================

------------
Core Widgets
------------

Toga includes a set of core widgets, that can be placed with a :doc:`Box </reference/widgets/box>` Container. 

==================== ============================================================ ====================================== =================================================================== 
Component            Usage                                                        Purpose                                Class                                                      
==================== ============================================================ ====================================== ===================================================================
Application          :doc:`Documentation </reference/widgets/app>`                Primary host for UI components         :mod:`toga.interface.app.App`       
Box                  :doc:`Documentation </reference/widgets/box>`                Container for components               :mod:`toga.interface.widgets.box.Box`           
Font                 :doc:`Documentation </reference/widgets/font>`               Fonts                                  :mod:`toga.interface.font.Font`           
Widget               :doc:`Documentation </reference/widgets/widget>`             Base class for widgets                 :mod:`toga.interface.widgets.base.Widget`           
Window               :doc:`Documentation </reference/widgets/window>`             Window object                          :mod:`toga.interface.window.Window`           
==================== ============================================================ ====================================== ===================================================================

---------------
General widgets
---------------

==================== ============================================================ ====================================== ===================================================================
Component            Usage                                                        Purpose                                Class                                                      
==================== ============================================================ ====================================== ===================================================================
Button               :doc:`Documentation </reference/widgets/button>`             Basic clickable button                 :mod:`toga.interface.widgets.button.Button`           
Image View           :doc:`Documentation </reference/widgets/imageview>`          Image Viewer                           :mod:`toga.interface.widgets.imageview.ImageView`           
Label                :doc:`Documentation </reference/widgets/label>`              Text label                             :mod:`toga.interface.widgets.label.Label`           
Multiline Text Input :doc:`Documentation </reference/widgets/multilinetextinput>` Multi-line Text Input field            :mod:`toga.interface.widgets.multilinetextinput.MultilineTextInput`           
Number Input         :doc:`Documentation </reference/widgets/numberinput>`        Number Input field                     :mod:`toga.interface.widgets.numberinput.NumberInput`           
Option Container     :doc:`Documentation </reference/widgets/optioncontainer>`    Option Container                       :mod:`toga.interface.widgets.optioncontainer.OptionContainer`           
Progress Bar         :doc:`Documentation </reference/widgets/progressbar>`        Progress Bar                           :mod:`toga.interface.widgets.progressbar.ProgressBar`           
Selection            :doc:`Documentation </reference/widgets/selection>`          Selection                              :mod:`toga.interface.widgets.selection.Selection`           
Text Input           :doc:`Documentation </reference/widgets/textinput>`          Text Input field                       :mod:`toga.interface.widgets.textinput.TextInput`           
Table                :doc:`Documentation </reference/widgets/table>`              Table of data                          :mod:`toga.interface.widgets.table.Table`           
Tree                 :doc:`Documentation </reference/widgets/tree>`               Tree of data                           :mod:`toga.interface.widgets.tree.Tree`           
==================== ============================================================ ====================================== ===================================================================

--------------
Layout widgets
--------------

==================== ============================================================ ====================================== =================================================================== 
Component            Usage                                                        Purpose                                Class                                                      
==================== ============================================================ ====================================== ===================================================================
Scroll Container     :doc:`Documentation </reference/widgets/scrollcontainer>`    Scrollable Container                   :mod:`toga.interface.widgets.scrollcontainer.ScrollContainer`           
Split Container      :doc:`Documentation </reference/widgets/splitcontainer>`     Split Container                        :mod:`toga.interface.widgets.splitcontainer.SplitContainer`           
Web View             :doc:`Documentation </reference/widgets/webview>`            Web View                               :mod:`toga.interface.widgets.webview.WebView`           
==================== ============================================================ ====================================== ===================================================================

-------------------
Supported Platforms
-------------------

.. include:: ../supported_platforms.rst